Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Fetcher ¶
type Fetcher interface {
Fetch(url string) (io.ReadCloser, error)
}
Fetcher download data from source
type Mock ¶
type Mock struct {
// contains filtered or unexported fields
}
Mock emulates fetcher behaviour
func (*Mock) Fetch ¶
func (f *Mock) Fetch(url string) (io.ReadCloser, error)
Fetch waits specified time and return result if presented
type SimpleFetcher ¶
type SimpleFetcher struct {
// contains filtered or unexported fields
}
SimpleFetcher download data from source and checks content type
func (SimpleFetcher) Fetch ¶
func (f SimpleFetcher) Fetch(url string) (io.ReadCloser, error)
Fetch retrieve data from url
Click to show internal directories.
Click to hide internal directories.